Channel

Struct Channel 

pub struct Channel<CH>(/* private fields */);
Trillium handler containing a ChannelHandler

This is constructed from a ChannelHandler using Channel::new and dereferences to that type.

Implementations

Source

impl<CH: ChannelHandler> Channel<CH>

pub fn new(channel_handler: CH) -> Self

Constructs a new trillium Channel handler from the provided ChannelHandler implementation

pub fn broadcaster(&self) -> ChannelBroadcaster

Retrieve a ChannelBroadcaster that can be moved elsewhere or cloned in order to trigger channel events and listen for global events.

pub fn broadcast(&self, event: impl Into<ChannelEvent>)

Send a ChannelEvent to all connected clients that subscribe to the topic