pub struct ChannelBroadcaster { /* private fields */ }Expand description
Channel-wide event broadcaster and subscriber
This can be cloned and stored elsewhere in an application in order to
send events to connected channel clients. Retrieve a ChannelBroadcaster from a
Channel by calling
Channel::broadcaster
ChannelBroadcaster also implements Stream so that your application
can listen in on ChannelEvents happening elsewhere. This might be used
for spawning a task to log events, or synchronizing events between
servers.
Implementations
Sourceimpl ChannelBroadcaster
impl ChannelBroadcaster
Sourcepub fn broadcast(&self, event: impl Into<ChannelEvent>)
pub fn broadcast(&self, event: impl Into<ChannelEvent>)
Send this ChannelEvent to all subscribed channel clients
Sourcepub fn connected_clients(&self) -> usize
pub fn connected_clients(&self) -> usize
Returns the number of connected clients. Note that the number of clients listening on any given channel will likely be smaller than this, and currently that number is not available.