pub struct Channel<CH>(/* private fields */);Expand description
Trillium handler containing a ChannelHandler
This is constructed from a ChannelHandler using Channel::new
and dereferences to that type.
Implementations
Sourceimpl<CH: ChannelHandler> Channel<CH>
impl<CH: ChannelHandler> Channel<CH>
Sourcepub fn new(channel_handler: CH) -> Self
pub fn new(channel_handler: CH) -> Self
Constructs a new trillium Channel handler from the provided
ChannelHandler implementation
Sourcepub fn broadcaster(&self) -> ChannelBroadcaster
pub fn broadcaster(&self) -> ChannelBroadcaster
Retrieve a ChannelBroadcaster that can be moved elsewhere or cloned in order to trigger channel events and listen for global events.
Sourcepub fn broadcast(&self, event: impl Into<ChannelEvent>)
pub fn broadcast(&self, event: impl Into<ChannelEvent>)
Send a ChannelEvent to all connected clients that subscribe to the topic